@@ -45,3 +45,13 @@ blockly_version:2.2.1
 
 """
 
+"""
+
+2022/3/21
+control_version:0.5.1
+blcoklyFile_version:0.2.0
+blockly_version:2.2.1
+更新内容：
+修改了在树莓派不能调用摄像头的bug
+
+"""
